pyxmpp2.mainloop.threads

Package pyxmpp2 :: Package mainloop :: Module threads |
[hide private]

# Module threads

I/O Handling classes

This module has a purpose similar to `asyncore` from the base library, but should be more usable, especially for PyXMPP.

Also, these interfaces should allow building application not only in asynchronous event loop model, but also threaded model.

Classes | [hide private]
| IOThread Base class for ReadingThread and WrittingThread.
| ReadingThread A thread reading from io_handler.
| WrittingThread A thread reading from io_handler.
| EventDispatcherThread Event dispatcher thread.
| TimeoutThread Thread to handle TimeoutHandler methods.
| ThreadPool Thread pool object, as a replacement for an asychronous event loop.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.mainloop.threads")`